@@ -15,3 +15,7 @@ like($movie->user_rating,qr/\d+\.?\d*/,"got a user_rating: " . $movie->user_rati
 is_deeply($movie->directors,['Scott, Ridley'],'right directors');
 is_deeply($movie->writers,['O\'Bannon, Dan','Shusett, Ronald'],'right writers');
 is_deeply($movie->genres, ['Sci-Fi','Horror','Thriller','Action'],'right genres');
+
+%tmpl = $movie->as_HTML_Template;
+is_deeply($tmpl{directors},[{name=>'Scott, Ridley'}],'correct HTML::Template format');
+is_deeply($movie->directors,['Scott, Ridley'],'deep copy successful');
